pub struct AttributeSet { /* private fields */ }Trait Implementations
Sourceimpl Decode for AttributeSet
impl Decode for AttributeSet
Sourcefn decode<__CodecInputEdqy: Input>(
__codec_input_edqy: &mut __CodecInputEdqy,
) -> Result<Self, Error>
fn decode<__CodecInputEdqy: Input>( __codec_input_edqy: &mut __CodecInputEdqy, ) -> Result<Self, Error>
Attempt to deserialise the value from input.
Sourcefn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
fn decode_into<I>(
input: &mut I,
dst: &mut MaybeUninit<Self>,
) -> Result<DecodeFinished, Error>where
I: Input,
Attempt to deserialize the value from input into a pre-allocated piece of memory. Read more
Sourceimpl Encode for AttributeSet
impl Encode for AttributeSet
Sourcefn size_hint(&self) -> usize
fn size_hint(&self) -> usize
If possible give a hint of expected size of the encoding. Read more
Sourcefn encode_to<__CodecOutputEdqy: Output + ?Sized>(
&self,
__codec_dest_edqy: &mut __CodecOutputEdqy,
)
fn encode_to<__CodecOutputEdqy: Output + ?Sized>( &self, __codec_dest_edqy: &mut __CodecOutputEdqy, )
Convert self to a slice and append it to the destination.
Sourcefn using_encoded<R, F>(&self, f: F) -> R
fn using_encoded<R, F>(&self, f: F) -> R
Convert self to a slice and then invoke the given closure with it.
Sourcefn encoded_size(&self) -> usize
fn encoded_size(&self) -> usize
Calculates the encoded size. Read more
Sourceimpl EventLenTopics for AttributeSet
impl EventLenTopics for AttributeSet
Sourceimpl From<AttributeSet> for __ink_EventBase
impl From<AttributeSet> for __ink_EventBase
Sourcefn from(event: AttributeSet) -> Self
fn from(event: AttributeSet) -> Self
Converts to this type from the input type.
Sourceimpl Topics for AttributeSet
impl Topics for AttributeSet
Sourcetype RemainingTopics = [HasRemainingTopics; 1]
type RemainingTopics = [HasRemainingTopics; 1]
Type state indicating how many event topics are to be expected by the topics
builder.
Sourcefn topics<E, B>(
&self,
builder: TopicsBuilder<Uninit, E, B>,
) -> <B as TopicsBuilderBackend<E>>::Outputwhere
E: Environment,
B: TopicsBuilderBackend<E>,
fn topics<E, B>(
&self,
builder: TopicsBuilder<Uninit, E, B>,
) -> <B as TopicsBuilderBackend<E>>::Outputwhere
E: Environment,
B: TopicsBuilderBackend<E>,
Guides event topic serialization using the given topics builder.
impl EncodeLike for AttributeSet